Tabbed Container Example
===============================================================================

:download:`tabbed.enaml <../../../examples/containers/tab_group.enaml>`

.. literalinclude:: ../../../examples/containers/tab_group.enaml
    :language: python

::

 $ enaml-run tab_group.enaml

.. image:: images/tabbed0.png

After two clicks on :guilabel:`Cycle Tab Position`

.. image:: images/tabbed1.png
